@@ -36,6 +36,8 @@
 
 int main( int argc, char *argv[] )
 {
+    QCoreApplication::setAttribute( Qt::AA_UseHighDpiPixmaps, true );
+    QCoreApplication::setAttribute( Qt::AA_EnableHighDpiScaling, true );
     QApplication app(argc, argv);
     app.setQuitOnLastWindowClosed( false );
     
@@ -47,7 +49,7 @@ int main( int argc, char *argv[] )
 
     KAboutData aboutData( "rsibreak",
                           i18n( "RSIBreak" ),
-                          "0.12.11",
+                          "0.12.12",
                           i18n( "Try to prevent Repetitive Strain Injury by "
                                  "reminding a user to rest." ),
                           KAboutLicense::GPL,
@@ -66,8 +68,6 @@ int main( int argc, char *argv[] )
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
-    parser.addVersionOption();
-    parser.addHelpOption();
     parser.addOption(QCommandLineOption("autostart"));
     aboutData.setupCommandLine(&parser);
     parser.process(app);
